@@ -1,12 +1,12 @@
 
 FILE=barnard-calibrated.fits
 
-cp astrometry/${FILE} ${ADTTMP}
-cd ${ADTTMP}
+cp astrometry/${FILE} ${AUTOPKGTEST_TMP}
+cd ${AUTOPKGTEST_TMP}
 
 munipack find -f 5 $FILE
 munipack aphot $FILE
-munipack cone -r 0.2 -- 269.5 4.6
+munipack cone -r 0.1 --par 'Vmag=<15' -- 269.44 4.69
 munipack astrometry $FILE
 munipack phcal --photsys-ref Johnson --area 0.3 \
 	 --col-ra RAJ2000 --col-dec DEJ2000 \
